<?php

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	class NC_WooCommerce {

		public static function init() {

			add_filter( 'nc_supported_types', __CLASS__ . '::extend_types' );
			add_filter( 'nc_supported_column_types', __CLASS__ . '::extend_column_types' );
			add_filter( 'nc_supported_posters', __CLASS__ . '::extend_posters' );

			add_filter( 'nc_loop_class', __CLASS__ . '::rename_loop' );
			add_action( 'newscodes_woocommerce', __CLASS__ . '::insert_product_data' );

			add_action( 'woocommerce_add_to_cart' , __CLASS__ . '::repair_cart' );
			add_action( 'wp_ajax_nopriv_nc_add_to_cart_callback', __CLASS__ . '::nc_add_to_cart_callback' );
			add_action( 'wp_ajax_nc_add_to_cart_callback', __CLASS__ . '::nc_add_to_cart_callback' );

		}

		public static function extend_types( $types ) {

			$woo_types = array (
				'woo-poster' => 'WooCommerce ' . esc_html__( 'Featured Poster', 'nwscds' ),
				'woo-grid' => 'WooCommerce ' . esc_html__( 'Grid', 'nwscds' ),
				'woo-columned-featured-list' => 'WooCommerce ' . esc_html__( 'Columned Featured List', 'nwscds' ),
				'woo-columned-featured-list-tiny' => 'WooCommerce ' . esc_html__( 'Columned Featured List Tiny', 'nwscds' ),
				'woo-columned-featured-list-compact' => 'WooCommerce ' . esc_html__( 'Columned Featured List Compact', 'nwscds' ),
				'woo-list' => 'WooCommerce ' . esc_html__( 'List', 'nwscds' ),
				'woo-list-featured' => 'WooCommerce ' . esc_html__( 'List with Featured', 'nwscds' ),
				'woo-list-compact' => 'WooCommerce ' . esc_html__( 'List Compact', 'nwscds' ),
				'woo-list-compact-featured' => 'WooCommerce ' . esc_html__( 'List Compact with Featured', 'nwscds' ),
				'woo-list-tiny' => 'WooCommerce ' . esc_html__( 'List Tiny', 'nwscds' ),
				'woo-list-tiny-featured' => 'WooCommerce ' . esc_html__( 'List Tiny with Featured', 'nwscds' ),
				'woo-marquee' => 'WooCommerce ' . esc_html__( 'Marquee', 'nwscds' ),
				'woo-ticker' => 'WooCommerce ' . esc_html__( 'Ticker', 'nwscds' ),
				'woo-ticker-compact' => 'WooCommerce ' . esc_html__( 'Ticker Compact', 'nwscds' ),
				'woo-ticker-tiny' => 'WooCommerce ' . esc_html__( 'Ticker Tiny', 'nwscds' ),
				'woo-one-tabbed-posts' => 'WooCommerce ' . esc_html__( 'One Tabbed Posts', 'nwscds' ),
				'woo-grid-author' => 'WooCommerce ' . esc_html__( 'Grid Author', 'nwscds' ),
				'woo-list-author-featured' => 'WooCommerce ' . esc_html__( 'List with Featured Author', 'nwscds' ),
				'woo-list-author-compact-featured' => 'WooCommerce ' . esc_html__( 'List Compact with Featured Author', 'nwscds' ),
				'woo-list-author-tiny-featured' => 'WooCommerce ' . esc_html__( 'List Tiny with Featured Author', 'nwscds' )
			);

			$types = array_merge( $types, $woo_types );
			return $types;
		}

		public static function extend_posters( $types ) {
			$types = array_merge( $types, array( 'woo-poster' ) );
			return $types;
		}
		public static function extend_column_types( $types ) {
			$types = array_merge( $types, array( 'woo-grid', 'woo-grid-author' ) );
			return $types;
		}

		public static function rename_loop( $class ) {
			if ( strpos( $class, 'nc-type-woo' ) > -1 ) {
				$class = ' newscodes-woo ' . str_replace(  'nc-type-woo',  'nc-type-news', $class );
			}
			return $class;
		}

		public static function insert_product_data() {

			$id = get_the_ID();

			if ( get_post_type( $id ) == 'product' ) {
				$product = wc_get_product( $id );
			?>
				<p class="nc-woo">
				<?php
					if ( !$product->is_type( 'variable' ) ) {
						$price = $product->get_regular_price();
						$sale_price = $product->get_sale_price();
						$price = $price > 0 ? wc_price( $price ) : $price;
						$sale_price = $sale_price > 0 ? wc_price( $sale_price ) : $sale_price;
					}
					else {
						$prices = array(
							$product->get_variation_regular_price( 'min' ),
							$product->get_variation_regular_price( 'max' ),
							$product->get_variation_sale_price( 'min' ),
							$product->get_variation_sale_price( 'max' )
						);

						$min = min( $prices );
						$max = max( $prices );
						$price = ( $min == $max ? wc_price( $min ) : wc_price( $min ) . ' - ' . wc_price( $max ) );
						$sale_price = '';
					}

					$price = !empty( $price ) ? '<span class="nc-woo-regular-price">' . strip_tags( $price ) . '</span>' : '';
					$sale_price = !empty( $sale_price ) ? '<span class="nc-woo-sale-price">' . strip_tags( $sale_price ) . '</span>' : '';

					if ( !empty( $price ) || !empty( $sale_price ) ) {
						printf( '<span class="nc-woo-prices">%1$s %2$s</span>', $price, $sale_price );
					}

					$type = method_exists( $product, 'get_type' ) ? $product->get_type() : $product->product_type;
					printf( '<a href="%s" rel="nofollow" data-product_id="%s" data-product_sku="%s" class="%s nc-read-more product_type_%s">%s</a>',
						esc_url( $product->add_to_cart_url() ),
						esc_attr( $id ),
						esc_attr( $product->get_sku() ),
						$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
						$type,
						esc_html( $product->add_to_cart_text() )
					);
				?>
				</p>
			<?php
			}

		}

		public static function nc_add_to_cart_callback() {

			$product_id = apply_filters( 'woocommerce_add_to_cart_product_id', absint( $_POST['product_id'] ) );
			$quantity = 1;

			$passed_validation = apply_filters( 'woocommerce_add_to_cart_validation', true, $product_id, $quantity );
		
			if ( $passed_validation && WC()->cart->add_to_cart( $product_id ) ) {
				do_action( 'woocommerce_ajax_added_to_cart', $product_id );

				$data = WC_AJAX::get_refreshed_fragments();
			}
			else {

					WC_AJAX::json_headers();

					$data = array(
						'error' => true,
						'product_url' => apply_filters( 'woocommerce_cart_redirect_after_error', get_permalink( $product_id ), $product_id )
					);

					$data = json_encode( $data );
			}

			die($data);
			exit();

		}

		public static function repair_cart(){
			if ( defined( 'DOING_AJAX' ) ) {
				wc_setcookie( 'woocommerce_items_in_cart', 1 );
				wc_setcookie( 'woocommerce_cart_hash', md5( json_encode( WC()->cart->get_cart() ) ) );
				do_action( 'woocommerce_set_cart_cookies', true );
			}
		}

	}

	NC_WooCommerce::init();

?>