<?php
/*
Plugin Name: Newscodes
Plugin URI: https://www.mihajlovicnenad.com/newscodes
Description: News elements for your Wordpress webiste! - http://www.mihajlovicnenad.com
Version: 2.3.2
Requires at least: 4.5
Tested up to: 5.0.3
WC requires at least: 3.0.0
WC tested up to: 3.5.4
Author: Mihajlovic Nenad
Author URI: https://www.mihajlovicnenad.com
Text Domain: nwscds
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'NewsCodes' ) ) :

	final class NewsCodes {

		public static $version = '2.3.2';

		protected static $_instance = null;

		public static function instance() {

			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		public function __construct() {
			do_action( 'newscodes_loading' );

			$this->includes();
			$this->init_hooks();

			do_action( 'newscodes_loaded' );
		}

		private function init_hooks() {
			register_activation_hook( __FILE__, array( 'NC_Setup', 'install' ) );
			add_action( 'after_setup_theme', array( $this, 'setup_environment' ) );
			add_action( 'after_setup_theme', array( $this, 'include_template_functions' ), 11 );
			add_action( 'init', array( $this, 'init' ), 0 );
			add_action( 'init', array( 'NC_Shortcodes', 'init' ), 0 );

			add_action( 'vc_before_init', array($this, 'composer') );
			add_action( 'cornerstone_load_elements', array( $this, 'cornerstone' ) );
			add_filter( 'cornerstone_icon_map', array( $this, 'cornerstone_icon_map' ) );

			add_filter( 'nc_supported_styles', array( $this, 'defaults' ), 10, 1 );
			add_filter( 'nc_load_less_styles', array( $this, 'load_styles' ), 10, 1 );
			add_filter( 'nc_load_google_fonts', array( $this, 'font_defaults' ), 10, 1 );
		}

		private function is_request( $type ) {
			switch ( $type ) {
				case 'admin' :
					return is_admin();
				case 'ajax' :
					return defined( 'DOING_AJAX' );
				case 'cron' :
					return defined( 'DOING_CRON' );
				case 'frontend' :
					return ( ! is_admin() || defined( 'DOING_AJAX' ) ) && ! defined( 'DOING_CRON' );
			}
		}

		public function includes() {

			if ( $this->is_request( 'admin' ) ) {

				include_once( 'includes/nc-admin-metaboxes.php' );
				include_once( 'includes/nc-admin-controls.php' );
				include_once( 'includes/nc-admin.php' );

			}

			if ( $this->is_request( 'frontend' ) ) {
				$this->frontend_includes();
			}

		}

		public function frontend_includes() {
			include_once( 'includes/nc-frontend.php' );
		}

		public function include_template_functions() {
			include_once( 'includes/nc-functions.php' );
		}

		public function init() {

			do_action( 'before_newscodes_init' );

			$this->load_plugin_textdomain();

			if ( class_exists( 'WooCommerce' ) ) {
				include_once( 'includes/nc-woocommerce.php' );
			}

			include_once( 'includes/nc-setup.php' );
			include_once( 'includes/nc-core.php' );
			include_once( 'includes/nc-shortcodes.php' );

			do_action( 'after_newscodes_init' );

		}

		public function load_plugin_textdomain() {

			$domain = 'newcodes';
			$dir = untrailingslashit( WP_LANG_DIR );
			$locale = apply_filters( 'plugin_locale', get_locale(), $domain );

			if ( $loaded = load_textdomain( $domain, $dir . '/plugins/' . $domain . '-' . $locale . '.mo' ) ) {
				return $loaded;
			}
			else {
				load_plugin_textdomain( $domain, FALSE, basename( dirname( __FILE__ ) ) . '/lang/' );
			}

		}

		public function setup_environment() {
		}

		public function plugin_url() {
			return untrailingslashit( plugins_url( '/', __FILE__ ) );
		}

		public function template_path() {
			return apply_filters( 'newscodes_template_path', 'newscodes/' );
		}

		public function plugin_path() {
			return untrailingslashit( plugin_dir_path( __FILE__ ) );
		}

		public function plugin_basename() {
			return untrailingslashit( plugin_basename( __FILE__ ) );
		}

		public function ajax_url() {
			return admin_url( 'admin-ajax.php', 'relative' );
		}

		public function cornerstone() {

			require_once( 'includes/nc-cornerstone.php' );

		}

		public function composer() {

			require_once( 'includes/nc-composer.php' );

		}

		public function cornerstone_icon_map( $icon_map ) {
			$icon_map['newscodes-map'] = NC()->plugin_url() . '/lib/images/cs-icon.svg';
			return $icon_map;
		}

		public function version() {
			return self::$version;
		}

		public function defaults( $styles ) {

			if ( !is_array( $styles ) ) {
				$styles = array();
			}

			return $styles + array( 'default' => array( 'name' => esc_html__( 'Default', 'nwscds' ), 'type' => 'default', 'styles' => array( 'classic-red-pt-serif' => array ( 'name' => 'Classic Red PT Serif', 'nc_heading' => array ( 'font-color' => '#222', 'font-family' => 'ggl-pT-serif', 'font-size' => '32px', 'font-style' => '', 'font-variant' => '', 'font-weight' => 'bold', 'letter-spacing' => '', 'line-height' => '36px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_heading_hover' => '#f00', 'nc_meta' => array ( 'font-color' => '#3a3a3a', 'font-family' => 'sys-arial', 'font-size' => '12px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '12px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'ggl-pT-serif', 'font-size' => '16px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#f00', 'nc_navigation' => array ( 'font-color' => '#8e8e8e', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#f00', 'nc_navigation_style' => 'background-color', 'nc_tabs' => array ( 'font-color' => '#8e8e8e', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#f00', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#f00', 'nc_tabs_padding' => 'default', 'nc_image_padding' => '35px', 'nc_meta_padding' => 'default', 'nc_heading_padding' => '25px', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => '35px', ), 'compact-red-open-sans' => array ( 'name' => 'Compact Red Open Sans', 'nc_heading' => array ( 'font-color' => '#222', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '700', 'letter-spacing' => '-0.02em', 'line-height' => '30px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_heading_hover' => '#f00', 'nc_meta' => array ( 'font-color' => '#ccc', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '300', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#f00', 'nc_navigation' => array ( 'font-color' => '#222222', 'font-family' => '', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '700', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#f00', 'nc_navigation_style' => 'text-only', 'nc_tabs' => array ( 'font-color' => '#ccc', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#f00', 'nc_tabs_style' => 'border', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#1f80e0', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'italic-red-ubuntu' => array ( 'name' => 'Italic Red Ubuntu', 'nc_heading' => array ( 'font-color' => '#222', 'font-family' => 'inc-ubuntu', 'font-size' => '', 'font-style' => 'italic', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_heading_hover' => '#f00', 'nc_meta' => array ( 'font-color' => '#ff0000', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-raleway', 'font-size' => '13px', 'font-style' => 'italic', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#f00', 'nc_navigation' => array ( 'font-color' => '#fafafa', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#f00', 'nc_navigation_style' => 'background-color', 'nc_tabs' => array ( 'font-color' => '#fafafa', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#f00', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#1f80e0', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'italic-red-ubuntu-on-right' => array ( 'name' => 'Italic Red Ubuntu on Right', 'nc_heading' => array ( 'font-color' => '#222', 'font-family' => 'inc-ubuntu', 'font-size' => '', 'font-style' => 'italic', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => 'right', ), 'nc_heading_hover' => '#f00', 'nc_meta' => array ( 'font-color' => '#ff0000', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'right', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-raleway', 'font-size' => '13px', 'font-style' => 'italic', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'right', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#f00', 'nc_navigation' => array ( 'font-color' => '#fafafa', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'right', ), 'nc_navigation_hover' => '#f00', 'nc_navigation_style' => 'background-color', 'nc_tabs' => array ( 'font-color' => '#fafafa', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'right', ), 'nc_tabs_hover' => '#f00', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#1f80e0', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'handwritten-blue' => array ( 'name' => 'Handwritten Blue', 'nc_heading' => array ( 'font-color' => '#1e73be', 'font-family' => 'ggl-annie-use-your-telescope', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '0.06em', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_heading_hover' => '#222222', 'nc_meta' => array ( 'font-color' => '#666666', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-opensans', 'font-size' => '16px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '300', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#1e73be', 'nc_navigation' => array ( 'font-color' => '#1e73be', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => 'bold', 'letter-spacing' => '', 'line-height' => '22px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#222222', 'nc_navigation_style' => 'background-color', 'nc_tabs' => array ( 'font-color' => '#1e73be', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#222222', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#1f80e0', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'light-orange-raleway' => array ( 'name' => 'Light Orange Raleway', 'nc_heading' => array ( 'font-color' => '#aaaaaa', 'font-family' => 'inc-raleway', 'font-size' => '36px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '200', 'letter-spacing' => '', 'line-height' => '42px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_heading_hover' => '#fc8a19', 'nc_meta' => array ( 'font-color' => '#ccc', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-raleway', 'font-size' => '16px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '200', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#fc8a19', 'nc_navigation' => array ( 'font-color' => '#ccc', 'font-family' => '', 'font-size' => '12px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '14px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_navigation_hover' => '#fc8a19', 'nc_navigation_style' => 'border', 'nc_tabs' => array ( 'font-color' => '#ccc', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_tabs_hover' => '#fc8a19', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#1f80e0', 'nc_tabs_padding' => 'default', 'nc_image_padding' => '45px', 'nc_meta_padding' => 'default', 'nc_heading_padding' => '40px', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => '30px', ), 'classic-blue-raleway' => array ( 'name' => 'Classic Blue Raleway', 'nc_heading' => array ( 'font-color' => '#222', 'font-family' => 'inc-raleway', 'font-size' => '32px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '300', 'letter-spacing' => '-0.05em', 'line-height' => '40px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_heading_hover' => '#1e73be', 'nc_meta' => array ( 'font-color' => '#fafafa', 'font-family' => 'inc-raleway', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#666666', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-raleway', 'font-size' => '16px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '24px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#1e73be', 'nc_navigation' => array ( 'font-color' => '#ccc', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#1e73be', 'nc_navigation_style' => 'background-color', 'nc_tabs' => array ( 'font-color' => '#ccc', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#1e73be', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#f00', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'classic-blue-raleway-centered' => array ( 'name' => 'Classic Blue Raleway Centered', 'nc_heading' => array ( 'font-color' => '#222', 'font-family' => 'inc-raleway', 'font-size' => '32px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '300', 'letter-spacing' => '-0.05em', 'line-height' => '40px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => 'center', ), 'nc_heading_hover' => '#1e73be', 'nc_meta' => array ( 'font-color' => '#fafafa', 'font-family' => 'inc-raleway', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_meta_background' => '#666666', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-raleway', 'font-size' => '16px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '24px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#1e73be', 'nc_navigation' => array ( 'font-color' => '#ccc', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_navigation_hover' => '#1e73be', 'nc_navigation_style' => 'background-color', 'nc_tabs' => array ( 'font-color' => '#ccc', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#1e73be', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#f00', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'light-travel-blue' => array ( 'name' => 'Light Travel Blue', 'nc_heading' => array ( 'font-color' => '#45ada8', 'font-family' => 'inc-lato', 'font-size' => '25px', 'font-style' => 'normal', 'font-variant' => 'normal', 'font-weight' => '300', 'letter-spacing' => '0.05em', 'line-height' => '', 'text-decoration' => 'none', 'text-transform' => 'uppercase', 'text-align' => 'left', ), 'nc_heading_hover' => '#547980', 'nc_meta' => array ( 'font-color' => '#594f4f', 'font-family' => 'inc-opensans', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-opensans', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#547980', 'nc_taxonomy_background' => '#e5fcc2', 'nc_navigation' => array ( 'font-color' => '#99b2b7', 'font-family' => 'inc-opensans', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#00a0b0', 'nc_navigation_style' => 'border', 'nc_tabs' => array ( 'font-color' => '#00b4cc', 'font-family' => 'inc-opensans', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#005f6b', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#f00', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'classic-red-pt-serif-centered' => array ( 'name' => 'Classic Red PT Serif Centered', 'nc_heading' => array ( 'font-color' => '#222', 'font-family' => 'ggl-pT-serif', 'font-size' => '32px', 'font-style' => '', 'font-variant' => '', 'font-weight' => 'bold', 'letter-spacing' => '', 'line-height' => '36px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => 'center', ), 'nc_heading_hover' => '#f00', 'nc_meta' => array ( 'font-color' => '#3a3a3a', 'font-family' => 'sys-arial', 'font-size' => '12px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '12px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'ggl-pT-serif', 'font-size' => '16px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#f00', 'nc_navigation' => array ( 'font-color' => '#8e8e8e', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_navigation_hover' => '#f00', 'nc_navigation_style' => 'background-color', 'nc_tabs' => array ( 'font-color' => '#8e8e8e', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#f00', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#f00', 'nc_tabs_padding' => 'default', 'nc_image_padding' => '35px', 'nc_meta_padding' => 'default', 'nc_heading_padding' => '25px', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => '35px', ), 'lowercase-brown-open-sans' => array ( 'name' => 'Lowercase Brown Open Sans', 'nc_heading' => array ( 'font-color' => '#222', 'font-family' => 'inc-opensans', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '100', 'letter-spacing' => '-0.03em', 'line-height' => '36px', 'text-decoration' => '', 'text-transform' => 'lowercase', 'text-align' => '', ), 'nc_heading_hover' => '#844a07', 'nc_meta' => array ( 'font-color' => '#444444', 'font-family' => 'inc-opensans', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '200', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fffde2', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '24px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#844a07', 'nc_navigation' => array ( 'font-color' => '#fffde2', 'font-family' => 'inc-opensans', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '200', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#844a07', 'nc_navigation_style' => 'background-color', 'nc_tabs' => array ( 'font-color' => '#fffde2', 'font-family' => 'inc-opensans', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '200', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#844a07', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#1f80e0', 'nc_tabs_padding' => '10px', 'nc_image_padding' => '20px', 'nc_meta_padding' => '10px', 'nc_heading_padding' => '5px', 'nc_excerpt_padding' => '10px', 'nc_pagination_padding' => '10px', ), 'dark-simple-crushed' => array ( 'name' => 'Dark Simple Crushed', 'nc_heading' => array ( 'font-color' => '#444444', 'font-family' => 'ggl-crushed', 'font-size' => '36px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '40px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_heading_hover' => '#f00', 'nc_meta' => array ( 'font-color' => '#ffffff', 'font-family' => 'inc-opensans', 'font-size' => '16px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '18px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#444444', 'nc_excerpt' => array ( 'font-color' => '#888888', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '24px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#ffffff', 'nc_taxonomy_background' => '#444444', 'nc_navigation' => array ( 'font-color' => '#fafafa', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#444444', 'nc_navigation_style' => 'background-color', 'nc_tabs' => array ( 'font-color' => '#fafafa', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#444444', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#1f80e0', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'dark-simple-crushed-centered' => array ( 'name' => 'Dark Simple Crushed Centered', 'nc_heading' => array ( 'font-color' => '#444444', 'font-family' => 'ggl-crushed', 'font-size' => '36px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '40px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => 'center', ), 'nc_heading_hover' => '#f00', 'nc_meta' => array ( 'font-color' => '#ffffff', 'font-family' => 'inc-opensans', 'font-size' => '16px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '18px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_meta_background' => '#444444', 'nc_excerpt' => array ( 'font-color' => '#888888', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '24px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_taxonomy_color' => '#ffffff', 'nc_taxonomy_background' => '#444444', 'nc_navigation' => array ( 'font-color' => '#fafafa', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_navigation_hover' => '#444444', 'nc_navigation_style' => 'background-color', 'nc_tabs' => array ( 'font-color' => '#fafafa', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#444444', 'nc_tabs_style' => 'background-color', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#1f80e0', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'flat-and-clean-yellow-ubuntu' => array ( 'name' => 'Flat and Clean Yellow Ubuntu', 'nc_heading' => array ( 'font-color' => '#222', 'font-family' => 'inc-ubuntu', 'font-size' => '32px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '36px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_heading_hover' => '#fadf00', 'nc_meta' => array ( 'font-color' => '#ffffff', 'font-family' => 'inc-opensans', 'font-size' => '14px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '14px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fadf00', 'nc_excerpt' => array ( 'font-color' => '#999999', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#fadf00', 'nc_navigation' => array ( 'font-color' => '#fafafa', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '22px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#fadf00', 'nc_navigation_style' => 'flat', 'nc_tabs' => array ( 'font-color' => '#fafafa', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#fadf00', 'nc_tabs_style' => 'flat', 'nc_format_standard' => '#888', 'nc_format_aside' => '#4358ab', 'nc_format_chat' => '#b1b1b1', 'nc_format_gallery' => '#b382e8', 'nc_format_link' => '#fb8c04', 'nc_format_image' => '#4fc03f', 'nc_format_quote' => '#332f53', 'nc_format_status' => '#92836d', 'nc_format_video' => '#f00', 'nc_format_audio' => '#1f80e0', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'stylish-blue-open-sans' => array ( 'name' => 'Stylish Blue Open Sans', 'nc_heading' => array ( 'font-color' => '#a0e5e0', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '30px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_heading_hover' => '#91bfb7', 'nc_meta' => array ( 'font-color' => '#ccc', 'font-family' => 'sys-arial', 'font-size' => '12px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '12px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#ffffff', 'nc_taxonomy_background' => '#e03e54', 'nc_navigation' => array ( 'font-color' => '#fafafa', 'font-family' => 'inc-opensans', 'font-size' => '14px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '24px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#a0e5e0', 'nc_navigation_style' => 'flat', 'nc_tabs' => array ( 'font-color' => '#ffffff', 'font-family' => 'inc-opensans', 'font-size' => '14px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#a0e5e0', 'nc_tabs_style' => 'flat', 'nc_format_standard' => '#e87162', 'nc_format_aside' => '#e87162', 'nc_format_chat' => '#e87162', 'nc_format_gallery' => '#e87162', 'nc_format_link' => '#e87162', 'nc_format_image' => '#e87162', 'nc_format_quote' => '#e87162', 'nc_format_status' => '#e87162', 'nc_format_video' => '#e87162', 'nc_format_audio' => '#e87162', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'sweet-and-red-ubuntu' => array ( 'name' => 'Sweet and Red Ubuntu', 'nc_heading' => array ( 'font-color' => '#444444', 'font-family' => 'inc-ubuntu', 'font-size' => '24px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '300', 'letter-spacing' => '', 'line-height' => '30px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_heading_hover' => '#f00', 'nc_meta' => array ( 'font-color' => '#ffffff', 'font-family' => 'inc-opensans', 'font-size' => '12px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_meta_background' => '#556270', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '22px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#f26565', 'nc_navigation' => array ( 'font-color' => '#f26565', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#c44d58', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#f26565', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#c44d58', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#f4b727', 'nc_format_aside' => '#f4d17f', 'nc_format_chat' => '#f4dba1', 'nc_format_gallery' => '#f4eede', 'nc_format_link' => '#f4e7c8', 'nc_format_image' => '#f4e0b0', 'nc_format_quote' => '#f4d386', 'nc_format_status' => '#f4c65a', 'nc_format_video' => '#f4b727', 'nc_format_audio' => '#f4f3e6', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'sweet-and-red-ubuntu-bigger-headlines' => array ( 'name' => 'Sweet and Red Ubuntu Bigger Headlines', 'nc_heading' => array ( 'font-color' => '#444444', 'font-family' => 'inc-ubuntu', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '600', 'letter-spacing' => '', 'line-height' => '40px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_heading_hover' => '#f00', 'nc_meta' => array ( 'font-color' => '#ffffff', 'font-family' => 'inc-opensans', 'font-size' => '12px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_meta_background' => '#556270', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '22px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#f26565', 'nc_navigation' => array ( 'font-color' => '#f26565', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#c44d58', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#f26565', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#c44d58', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#f4b727', 'nc_format_aside' => '#f4d17f', 'nc_format_chat' => '#f4dba1', 'nc_format_gallery' => '#f4eede', 'nc_format_link' => '#f4e7c8', 'nc_format_image' => '#f4e0b0', 'nc_format_quote' => '#f4d386', 'nc_format_status' => '#f4c65a', 'nc_format_video' => '#f4b727', 'nc_format_audio' => '#f4f3e6', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'sweet-and-blue-ubuntu-bigger-headings' => array ( 'name' => 'Sweet and Blue Ubuntu Bigger Headings', 'nc_heading' => array ( 'font-color' => '#444444', 'font-family' => 'inc-ubuntu', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '600', 'letter-spacing' => '', 'line-height' => '40px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_heading_hover' => '#1e73be', 'nc_meta' => array ( 'font-color' => '#ffffff', 'font-family' => 'inc-opensans', 'font-size' => '12px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_meta_background' => '#556270', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '22px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#70b2d8', 'nc_navigation' => array ( 'font-color' => '#70b2d8', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#2998d8', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#70b2d8', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#2998d8', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#f4b727', 'nc_format_aside' => '#f4d17f', 'nc_format_chat' => '#f4dba1', 'nc_format_gallery' => '#f4eede', 'nc_format_link' => '#f4e7c8', 'nc_format_image' => '#f4e0b0', 'nc_format_quote' => '#f4d386', 'nc_format_status' => '#f4c65a', 'nc_format_video' => '#f4b727', 'nc_format_audio' => '#f4f3e6', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'sweet-and-blue-ubuntu' => array ( 'name' => 'Sweet and Blue Ubuntu', 'nc_heading' => array ( 'font-color' => '#444444', 'font-family' => 'inc-ubuntu', 'font-size' => '24px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '300', 'letter-spacing' => '', 'line-height' => '30px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_heading_hover' => '#1e73be', 'nc_meta' => array ( 'font-color' => '#ffffff', 'font-family' => 'inc-opensans', 'font-size' => '12px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '500', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => 'none', 'text-align' => '', ), 'nc_meta_background' => '#556270', 'nc_excerpt' => array ( 'font-color' => '#777', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '22px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#70b2d8', 'nc_navigation' => array ( 'font-color' => '#70b2d8', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#2998d8', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#70b2d8', 'font-family' => '', 'font-size' => '', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#2998d8', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#f4b727', 'nc_format_aside' => '#f4d17f', 'nc_format_chat' => '#f4dba1', 'nc_format_gallery' => '#f4eede', 'nc_format_link' => '#f4e7c8', 'nc_format_image' => '#f4e0b0', 'nc_format_quote' => '#f4d386', 'nc_format_status' => '#f4c65a', 'nc_format_video' => '#f4b727', 'nc_format_audio' => '#f4f3e6', 'nc_tabs_padding' => 'default', 'nc_image_padding' => 'default', 'nc_meta_padding' => 'default', 'nc_heading_padding' => 'default', 'nc_excerpt_padding' => 'default', 'nc_pagination_padding' => 'default', ), 'with-impact-orange-oswald' => array ( 'name' => 'With Impact Orange Oswald', 'nc_heading' => array ( 'font-color' => '#1c140d', 'font-family' => 'ggl-oswald', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '600', 'letter-spacing' => '-0.02em', 'line-height' => '34px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_heading_hover' => '#f2c298', 'nc_meta' => array ( 'font-color' => '#f2c298', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '13px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#1c140d', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#f2c298', 'nc_navigation' => array ( 'font-color' => '#f2e9e1', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#f2c298', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#f2e9e1', 'font-family' => '', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#f2c298', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#6b96bf', 'nc_format_aside' => '#6b96bf', 'nc_format_chat' => '#6b96bf', 'nc_format_gallery' => '#6b96bf', 'nc_format_link' => '#6b96bf', 'nc_format_image' => '#6b96bf', 'nc_format_quote' => '#6b96bf', 'nc_format_status' => '#6b96bf', 'nc_format_video' => '#6b96bf', 'nc_format_audio' => '#6b96bf', 'nc_tabs_padding' => '15px', 'nc_image_padding' => '25px', 'nc_meta_padding' => '15px', 'nc_heading_padding' => '10px', 'nc_excerpt_padding' => '15px', 'nc_pagination_padding' => '15px', ), 'with-impact-green-oswald' => array ( 'name' => 'With Impact Green Oswald', 'nc_heading' => array ( 'font-color' => '#1c140d', 'font-family' => 'ggl-oswald', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '600', 'letter-spacing' => '-0.02em', 'line-height' => '34px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_heading_hover' => '#cbe86b', 'nc_meta' => array ( 'font-color' => '#cbe86b', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '13px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#1c140d', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#cbe86b', 'nc_navigation' => array ( 'font-color' => '#d9e8a9', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#cbe86b', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#d9e8a9', 'font-family' => '', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#cbe86b', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#6b96bf', 'nc_format_aside' => '#6b96bf', 'nc_format_chat' => '#6b96bf', 'nc_format_gallery' => '#6b96bf', 'nc_format_link' => '#6b96bf', 'nc_format_image' => '#6b96bf', 'nc_format_quote' => '#6b96bf', 'nc_format_status' => '#6b96bf', 'nc_format_video' => '#6b96bf', 'nc_format_audio' => '#6b96bf', 'nc_tabs_padding' => '15px', 'nc_image_padding' => '25px', 'nc_meta_padding' => '15px', 'nc_heading_padding' => '10px', 'nc_excerpt_padding' => '15px', 'nc_pagination_padding' => '15px', ), 'with-impact-green-oswald-centered' => array ( 'name' => 'With Impact Green Oswald Centered', 'nc_heading' => array ( 'font-color' => '#1c140d', 'font-family' => 'ggl-oswald', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '600', 'letter-spacing' => '-0.02em', 'line-height' => '34px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_heading_hover' => '#cbe86b', 'nc_meta' => array ( 'font-color' => '#cbe86b', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '13px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#1c140d', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#cbe86b', 'nc_navigation' => array ( 'font-color' => '#d9e8a9', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_navigation_hover' => '#cbe86b', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#d9e8a9', 'font-family' => '', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#cbe86b', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#6b96bf', 'nc_format_aside' => '#6b96bf', 'nc_format_chat' => '#6b96bf', 'nc_format_gallery' => '#6b96bf', 'nc_format_link' => '#6b96bf', 'nc_format_image' => '#6b96bf', 'nc_format_quote' => '#6b96bf', 'nc_format_status' => '#6b96bf', 'nc_format_video' => '#6b96bf', 'nc_format_audio' => '#6b96bf', 'nc_tabs_padding' => '15px', 'nc_image_padding' => '25px', 'nc_meta_padding' => '15px', 'nc_heading_padding' => '10px', 'nc_excerpt_padding' => '15px', 'nc_pagination_padding' => '15px', ), 'with-impact-orange-oswald-centered' => array ( 'name' => 'With Impact Orange Oswald Centered', 'nc_heading' => array ( 'font-color' => '#1c140d', 'font-family' => 'ggl-oswald', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '600', 'letter-spacing' => '-0.02em', 'line-height' => '34px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_heading_hover' => '#f2c298', 'nc_meta' => array ( 'font-color' => '#f2c298', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '13px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#1c140d', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#f2c298', 'nc_navigation' => array ( 'font-color' => '#f2e9e1', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_navigation_hover' => '#f2c298', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#f2e9e1', 'font-family' => '', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#f2c298', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#6b96bf', 'nc_format_aside' => '#6b96bf', 'nc_format_chat' => '#6b96bf', 'nc_format_gallery' => '#6b96bf', 'nc_format_link' => '#6b96bf', 'nc_format_image' => '#6b96bf', 'nc_format_quote' => '#6b96bf', 'nc_format_status' => '#6b96bf', 'nc_format_video' => '#6b96bf', 'nc_format_audio' => '#6b96bf', 'nc_tabs_padding' => '15px', 'nc_image_padding' => '25px', 'nc_meta_padding' => '15px', 'nc_heading_padding' => '10px', 'nc_excerpt_padding' => '15px', 'nc_pagination_padding' => '15px', ), 'with-impact-yellow-oswald' => array ( 'name' => 'With Impact Yellow Oswald', 'nc_heading' => array ( 'font-color' => '#1c140d', 'font-family' => 'ggl-oswald', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '600', 'letter-spacing' => '-0.02em', 'line-height' => '34px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_heading_hover' => '#edc951', 'nc_meta' => array ( 'font-color' => '#edc951', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '13px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#1c140d', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#edc951', 'nc_navigation' => array ( 'font-color' => '#ede2c0', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#edc951', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#ede2c0', 'font-family' => '', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#edc951', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#6b96bf', 'nc_format_aside' => '#6b96bf', 'nc_format_chat' => '#6b96bf', 'nc_format_gallery' => '#6b96bf', 'nc_format_link' => '#6b96bf', 'nc_format_image' => '#6b96bf', 'nc_format_quote' => '#6b96bf', 'nc_format_status' => '#6b96bf', 'nc_format_video' => '#6b96bf', 'nc_format_audio' => '#6b96bf', 'nc_tabs_padding' => '15px', 'nc_image_padding' => '25px', 'nc_meta_padding' => '15px', 'nc_heading_padding' => '10px', 'nc_excerpt_padding' => '15px', 'nc_pagination_padding' => '15px', ), 'with-impact-orange-yellow-centered' => array ( 'name' => 'With Impact Orange Yellow Centered', 'nc_heading' => array ( 'font-color' => '#1c140d', 'font-family' => 'ggl-oswald', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '600', 'letter-spacing' => '-0.02em', 'line-height' => '34px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_heading_hover' => '#edc951', 'nc_meta' => array ( 'font-color' => '#edc951', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '13px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#1c140d', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#edc951', 'nc_navigation' => array ( 'font-color' => '#ede2c0', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_navigation_hover' => '#edc951', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#ede2c0', 'font-family' => '', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#edc951', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#6b96bf', 'nc_format_aside' => '#6b96bf', 'nc_format_chat' => '#6b96bf', 'nc_format_gallery' => '#6b96bf', 'nc_format_link' => '#6b96bf', 'nc_format_image' => '#6b96bf', 'nc_format_quote' => '#6b96bf', 'nc_format_status' => '#6b96bf', 'nc_format_video' => '#6b96bf', 'nc_format_audio' => '#6b96bf', 'nc_tabs_padding' => '15px', 'nc_image_padding' => '25px', 'nc_meta_padding' => '15px', 'nc_heading_padding' => '10px', 'nc_excerpt_padding' => '15px', 'nc_pagination_padding' => '15px', ), 'with-impact-pale-oswald' => array ( 'name' => 'With Impact Pale Oswald', 'nc_heading' => array ( 'font-color' => '#1c140d', 'font-family' => 'ggl-oswald', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '600', 'letter-spacing' => '-0.02em', 'line-height' => '34px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_heading_hover' => '#b9d7d9', 'nc_meta' => array ( 'font-color' => '#b9d7d9', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '13px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#1c140d', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#b9d7d9', 'nc_navigation' => array ( 'font-color' => '#deeeef', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_navigation_hover' => '#b9d7d9', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#deeeef', 'font-family' => '', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#b9d7d9', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#6b96bf', 'nc_format_aside' => '#6b96bf', 'nc_format_chat' => '#6b96bf', 'nc_format_gallery' => '#6b96bf', 'nc_format_link' => '#6b96bf', 'nc_format_image' => '#6b96bf', 'nc_format_quote' => '#6b96bf', 'nc_format_status' => '#6b96bf', 'nc_format_video' => '#6b96bf', 'nc_format_audio' => '#6b96bf', 'nc_tabs_padding' => '15px', 'nc_image_padding' => '25px', 'nc_meta_padding' => '15px', 'nc_heading_padding' => '10px', 'nc_excerpt_padding' => '15px', 'nc_pagination_padding' => '15px', ), 'with-impact-pale-oswald-centered' => array ( 'name' => 'With Impact Pale Oswald Centered', 'nc_heading' => array ( 'font-color' => '#1c140d', 'font-family' => 'ggl-oswald', 'font-size' => '30px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '600', 'letter-spacing' => '-0.02em', 'line-height' => '34px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_heading_hover' => '#b9d7d9', 'nc_meta' => array ( 'font-color' => '#b9d7d9', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '13px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_meta_background' => '#fff', 'nc_excerpt' => array ( 'font-color' => '#1c140d', 'font-family' => 'inc-opensans', 'font-size' => '13px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_taxonomy_color' => '#fff', 'nc_taxonomy_background' => '#b9d7d9', 'nc_navigation' => array ( 'font-color' => '#deeeef', 'font-family' => 'inc-opensans', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '26px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => 'center', ), 'nc_navigation_hover' => '#b9d7d9', 'nc_navigation_style' => '3d', 'nc_tabs' => array ( 'font-color' => '#deeeef', 'font-family' => '', 'font-size' => '15px', 'font-style' => '', 'font-variant' => '', 'font-weight' => '', 'letter-spacing' => '', 'line-height' => '20px', 'text-decoration' => '', 'text-transform' => '', 'text-align' => '', ), 'nc_tabs_hover' => '#b9d7d9', 'nc_tabs_style' => '3d', 'nc_format_standard' => '#6b96bf', 'nc_format_aside' => '#6b96bf', 'nc_format_chat' => '#6b96bf', 'nc_format_gallery' => '#6b96bf', 'nc_format_link' => '#6b96bf', 'nc_format_image' => '#6b96bf', 'nc_format_quote' => '#6b96bf', 'nc_format_status' => '#6b96bf', 'nc_format_video' => '#6b96bf', 'nc_format_audio' => '#6b96bf', 'nc_tabs_padding' => '15px', 'nc_image_padding' => '25px', 'nc_meta_padding' => '15px', 'nc_heading_padding' => '10px', 'nc_excerpt_padding' => '15px', 'nc_pagination_padding' => '15px', ) ) ) );
		}

		public function load_styles( $styles ) {

			$styles['default']['id'] = 'default';
			$styles['default']['url'] =  NC()->plugin_url() . '/lib/css/newscodes-styles.css';

			return $styles;

		}

	}

	function NC() {
		return NewsCodes::instance();
	}

	NewsCodes::instance();

endif;

?>